package com.ruoyi.web.yh.price.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.web.yh.price.domain.dto.PriceVerifyDTO;
import com.ruoyi.web.yh.price.service.PriceConverter;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.web.yh.price.domain.Price;
import com.ruoyi.web.yh.price.domain.PriceVO;
import com.ruoyi.web.yh.price.domain.PriceQuery;
import com.ruoyi.web.yh.price.service.PriceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 单价Controller
 *
 * @author ruoyi
 * @date 2024-10-17
 */
@RestController
@RequestMapping("/yh/price")
public class PriceController extends BaseController
{
    @Autowired
    private PriceService priceService;

    @Autowired
    private PriceConverter priceConverter;

    @PreAuthorize("@ss.hasPermi('yh:price:list')")
    @GetMapping("/list")
    @DataScope(deptAlias = "sd")
    public TableDataInfo list(PriceQuery query)
    {
        startPage();
        startOrderBy();
        List<PriceVO> list = priceService.selectPriceList(query);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('yh:price:export')")
    @Log(title = "单价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @DataScope(deptAlias = "sd")
    public void export(HttpServletResponse response, PriceQuery query)
    {
        List<PriceVO> list = priceService.selectPriceList(query);
        ExcelUtil<PriceVO> util = new ExcelUtil<PriceVO>(PriceVO.class);
        util.exportExcel(response, list, "单价数据");
    }

    @PreAuthorize("@ss.hasPermi('yh:price:query')")
    @GetMapping(value = "/{priceId}")
    public AjaxResult getInfo(@PathVariable("priceId") Long priceId)
    {
        return success(priceService.selectPriceByPriceId(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:add')")
    @Log(title = "单价新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Price data)
    {
        Price po = priceConverter.toPoByCreate(data);
        return toAjax(priceService.insertPrice(po));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:edit')")
    @Log(title = "单价修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Price data)
    {
        Price po = priceConverter.toPoByUpdate(data);
        return toAjax(priceService.updatePrice(po));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:submit')")
    @Log(title = "单价提交", businessType = BusinessType.UPDATE)
    @PutMapping("/{priceId}/submit")
    public AjaxResult submit(@PathVariable Long priceId) {
        return toAjax(priceService.submit(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:cancel')")
    @Log(title = "单价取消提交", businessType = BusinessType.UPDATE)
    @PutMapping("/{priceId}/cancel")
    public AjaxResult cancel(@PathVariable Long priceId) {
        return toAjax(priceService.cancel(priceId));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:verify')")
    @Log(title = "单价审核", businessType = BusinessType.UPDATE)
    @PutMapping("/verify")
    public AjaxResult submit(@RequestBody @Validated PriceVerifyDTO dto) {
        dto.setVerifyUser(SecurityUtils.getLoginUser().getUser());
        return toAjax(priceService.verify(dto));
    }

    @PreAuthorize("@ss.hasPermi('yh:price:disable')")
    @Log(title = "单价禁用", businessType = BusinessType.OTHER)
    @PutMapping("/{priceId}/disable")
    public AjaxResult disable(@PathVariable Long priceId) {
        return toAjax(priceService.disable(priceId));
    }

}
